SystemOrganization addCategory: #'Seaside-Tests-Session'!

WAContextTest subclass: #WAInteractionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAInteractionTest commentStamp: 'pmm 4/6/2008 15:22' prior: 0!
The purpose of WAInteractionTest is to provide a fully initialized WContext all the neccsary objects are are normally there in a Seaside application like request, response, dispatcher applicaion, session and so forth.!

!WAInteractionTest methodsFor: 'accessing' stamp: 'jf 1/21/2009 12:19'!
application
	^self requestContext application! !

!WAInteractionTest methodsFor: 'private' stamp: 'lr 1/21/2009 15:11'!
createHandlers
	| dispatcher application session |
	dispatcher := WADispatcher named: 'rails'.
	application := (WAApplication named: 'homepage')
		setParent: dispatcher;
		yourself.
	session := WASession new.

	^super createHandlers, (Array with: dispatcher with: application with: session)! !

!WAInteractionTest methodsFor: 'accessing' stamp: 'jf 1/21/2009 12:19'!
session
	^self requestContext session! !

!WAInteractionTest methodsFor: 'testing' stamp: 'pmm 4/6/2008 15:27'!
testContentType
	| contentType |
	self application preferenceAt: #mimeType put: 'application/xhtml+xml'.
	self application preferenceAt: #charSet put: 'iso-8859-1'.
	
	contentType := WAResponse new contentType.
	self assert: contentType main = 'application'.
	self assert: contentType sub = 'xhtml+xml'.
	self assert: contentType charset = 'iso-8859-1'! !

!WAInteractionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:33'!
testDeleteNetscapeCookie
	| requestCookie responseCookies responseCookie |
	self application preferenceAt: #serverPath put: '/en/private_kunden/wealth_management'.
	requestCookie := WARequestCookie key: 'password' value: 'sex'.
	self requestContextWithUrl: '/' cookies: (Array with: requestCookie).
	self requestContext response deleteCookie: requestCookie.
	
	responseCookies := self requestContext response cookies.
	self assert: responseCookies size = 1.
	responseCookie := responseCookies anyOne.
	
	self assert: (responseCookie isKindOf: WACookie).
	self assert: responseCookie value = ''.
	self assert: responseCookie path = self application baseUrl pathString! !

!WAInteractionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:34'!
testDeleteRfc2965Cookie
	| requestCookie responseCookies responseCookie |
	requestCookie := (WARequestCookie key: 'password' value: 'sex')
		path: '/en/private_kunden/wealth_management';
		version: 1;
		yourself.
	self requestContextWithUrl: '/' cookies: (Array with: requestCookie).
	self requestContext response deleteCookie: requestCookie.
	
	responseCookies := self requestContext response cookies.
	self assert: responseCookies size = 1.
	responseCookie := responseCookies anyOne.
	
	self assert: (responseCookie isKindOf: WACookie).
	self assert: responseCookie value = ''.
	self assert: responseCookie path = '/en/private_kunden/wealth_management'! !

!WAInteractionTest methodsFor: 'testing' stamp: 'jf 1/21/2009 12:20'!
testNewCookie
	| cookie |
	cookie := self requestContext newCookie.
	self assert: cookie path = self application baseUrl pathString.
	self assert: cookie ports isNil.
	self assert: cookie httpOnly.
	self deny: cookie secure.
	self assert: cookie domain isNil.
	
	self application preferenceAt: #serverPath put: '/en/private_kunden/wealth_management'.
	cookie := self requestContext newCookie.
	self assert: cookie path = '/en/private_kunden/wealth_management'.
	self assert: cookie ports isNil.
	self assert: cookie httpOnly.
	self deny: cookie secure.
	self assert: cookie domain isNil.
	
	self application preferenceAt: #serverPort put: 8080.
	self application preferenceAt: #serverProtocol put: 'https'.
	self application preferenceAt: #serverHostname put: 'www.lgt.com'.
	cookie := self requestContext newCookie.
	self assert: cookie path = '/en/private_kunden/wealth_management'.
	self deny: cookie ports isNil.
	self assert: cookie ports size = 1.
	self assert: cookie ports first = 8080.
	self assert: cookie httpOnly.
	self assert: cookie secure.
	self assert: cookie domain = 'www.lgt.com'! !

!WAPackage class methodsFor: '*seaside-tests-session' stamp: 'lr 10/23/2008 21:36'!
seasideTestsSession
	^ self new
		name: 'Seaside-Tests-Session';
		description: 'Unit tests for the package Seaside-Session.';
		addDependency: 'Seaside-Session';
		addDependency: 'Seaside-Tests-Core';
		yourself! !

TestCase subclass: #WACurrentSessionTest
	instanceVariableNames: 'savedContinuation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WACurrentSessionTest commentStamp: 'pmm 3/29/2008 12:34' prior: 0!
A WACurrentSessionTest is to make sure

WACurrentSession value

works as in Seaside 2.9 as it did in earlier versions.
!

!WACurrentSessionTest methodsFor: 'running' stamp: 'lr 4/9/2008 09:38'!
setUp
	super setUp.
	WACurrentRequestContext reset! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:16'!
testBalancedContextContinuations
	"Cause the ensure blocks in WAContext to fire - use balanced nesting and things work fine"
	| x session alternateSession tertiarySession quatenarySession context |
	session := WASession new.
	alternateSession := WASession new.
	tertiarySession := WASession new.
	quatenarySession := WASession new.
	context := WARequestContext request: nil response: nil.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: tertiarySession
				while: 
					[ self assert: WACurrentRequestContext value session == tertiarySession.
					WACurrentRequestContext value 
						push: session
						while: 
							[ x := WAContinuation currentDo: 
								[ :cc | 
								savedContinuation := cc.
								0 ].
							x == 0 
								ifTrue: [ self assert: WACurrentRequestContext value session == session ]
								ifFalse: 
									[ self assert: x = 1.
									self assert: WACurrentRequestContext value session == quatenarySession ] ].
					x == 0 ifTrue: 
						[ self assert: WACurrentRequestContext value session == tertiarySession ].
					x == 1 ifTrue: 
						[ self assert: WACurrentRequestContext value session == alternateSession ] ] ].
	x ~~ 1 ifTrue: 
		[ WACurrentRequestContext 
			use: context
			during: 
				[ WACurrentRequestContext value 
					push: alternateSession
					while: 
						[ WACurrentRequestContext value 
							push: quatenarySession
							while: [ savedContinuation value: 1 ] ] ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:16'!
testContinuationInheritance
	"Verify that continuation inherits it's context from parent process"
	| x session alternateSession context |
	session := WASession new.
	alternateSession := WASession new.
	context := WARequestContext request: nil response: nil.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: 
					[ x := WAContinuation currentDo: 
						[ :cc | 
						savedContinuation := cc.
						0 ].
					x == 0 
						ifTrue: [ self assert: WACurrentRequestContext value session == session ]
						ifFalse: 
							[ self assert: x = 1.
							self assert: WACurrentRequestContext value session == alternateSession ] ] ].
	x ~~ 1 ifTrue: 
		[ WACurrentRequestContext 
			use: context
			during: 
				[ WACurrentRequestContext value 
					push: alternateSession
					while: [ savedContinuation value: 1 ] ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:16'!
testContinuations
	"verify that process variable not copied by continuation."
	| x session context |
	session := WASession new.
	context := WARequestContext request: nil response: nil.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: 
					[ x := WAContinuation currentDo: 
						[ :cc | 
						savedContinuation := cc.
						0 ].
					x == 0 ifTrue: 
						[ self assert: WACurrentSession value == session.
						"invoke continuation for the first time - reuse process variables"
						savedContinuation value: 1 ].
					x == 1 ifTrue: 
						[ self assert: WACurrentSession value = session.
						WACurrentRequestContext reset.
						"invoke continuation for the second time - process variables reset"
						savedContinuation value: 2 ].
					"no value for WACurrentSession after continuation invoked for second time"
					self assert: x = 2.
					self assert: WACurrentSession value isNil ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:17'!
testSimpleContinuation
	"verify that continuation reuses the process variable from the current process."
	| x continuation session context |
	session := WASession new.
	context := WARequestContext request: nil response: nil.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: 
					[ x := WAContinuation currentDo: 
						[ :cc | 
						continuation := cc.
						false ].
					self assert: WACurrentSession value = session.
					x ifFalse: [ continuation value: true ].
					self assert: x ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:17'!
testWithValue
	| session context |
	session := WASession new.
	context := WARequestContext request: nil response: nil.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: [ self assert: WACurrentSession value = session ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'pmm 3/29/2008 12:35'!
testWithoutValue
	self assert: WACurrentSession value isNil! !

WASession subclass: #WATestSession
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WATestSession methodsFor: 'processing' stamp: 'jf 1/30/2009 14:53'!
start
	self requestContext response nextPutAll: 'start: ', self key! !

WARegistryKeyHandlingTest subclass: #WAApplicationKeyHandlingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAApplicationKeyHandlingTest class methodsFor: 'testing' stamp: 'jf 1/30/2009 13:30'!
shouldInheritSelectors
	^ true! !

!WAApplicationKeyHandlingTest methodsFor: 'private' stamp: 'jf 1/30/2009 16:09'!
assertDefault: aResponse
	"Instead of returning 404 on a default request as WARegistry does, WAApplication creates a new
	Session and dispatches to it."
	self assert: registry cache size = (registrySize + 1).
	self assert: aResponse status = 200.
	self assert: (aResponse contents beginsWith: 'start:')! !

!WAApplicationKeyHandlingTest methodsFor: 'private' stamp: 'jf 1/30/2009 14:51'!
createRegistry
	^ (WAApplication named: self registryName)
		preferenceAt: #sessionClass put: WATestSession;
		yourself! !

!WAApplicationKeyHandlingTest methodsFor: 'private' stamp: 'jf 1/30/2009 13:16'!
fieldName
	^ '_s'! !

!WAApplicationKeyHandlingTest methodsFor: 'testing' stamp: 'jf 1/30/2009 16:15'!
testNoKey
	"There is no URL field and no cookie. This is a new request to the Registry.
	
	Instead of returning a 404, like WARegistry does, WAApplication creates a new WASession
	and also adds the cookie."
	
	| response context |
	registry := self createRegistryWithCookiesEnabled.
	context := self createRequestContextWithFieldKey: nil cookieKey: nil.
	response := self dispatch: context to: registry.
	
	self assertCookieAddition: response.
	self assert: ((registry cache at: response cookies first value) isKindOf: WASession).
	self assertDefault: response! !

WARegistryTest subclass: #WAApplicationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAApplicationTest class methodsFor: 'testing' stamp: 'jf 1/29/2009 20:59'!
shouldInheritSelectors
	^ true! !

!WAApplicationTest methodsFor: 'running' stamp: 'jf 10/7/2008 01:36'!
newEntryPoint
	^ WAApplication named: 'app'! !

!WAApplicationTest methodsFor: 'running' stamp: 'pmm 11/30/2008 16:02'!
requestWithMethod: aString
	^WARequest
		method: aString
		url: '/oneo'
		headers: Dictionary new
		fields: Dictionary new
		cookies: Array new
		remoteAddress: '127.0.0.1'! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 1/29/2009 21:19'!
testNotImplemented
	| context request |
	#('OPTIONS' 'HEAD' 'PUT' 'DELETE' 'TRACE' 'CONNECT') do: [ :each |
		request := self requestWithMethod: each.
		context := WARequestContext request: request response: WABufferedResponse new.
		[ handler handle: context ]
			on: WAResponseNotification
			do: [ :notification | ].
		self assert: context response status = 501 ].
	
	#('GET' 'POST') do: [ :each |
		request := self requestWithMethod: each.
		context := WARequestContext request: request response: WABufferedResponse new.
		[ handler handle: context ]
			on: WAResponseNotification
			do: [ :notification | ].
		self assert: context response status ~= 501 ]! !
